@@ -77,12 +77,14 @@ class Camera(BaseCamera):
 
         # -----------get parameters for DetMot, same for web as for all
         target_frame = config.CONFIG['target_frame']
-        average      = config.CONFIG['average']
-        threshold    = config.CONFIG['threshold']
-        blur         = config.CONFIG['blur']
-        timelaps     = config.CONFIG['timelaps']
+        average      = int(config.CONFIG['average'])
+        threshold    = int(config.CONFIG['threshold'])
+        blur         = int(config.CONFIG['blur'])
+        timelaps     = int(config.CONFIG['timelaps'])
         histogram    = config.CONFIG['histogram']
         res          = config.CONFIG['resolution']
+        speedx          = float(config.CONFIG['x'])
+        speedy          = float(config.CONFIG['y'])
 
         camera = Camera(  )
         cap, vidnum = camera.init_cam(  )
@@ -166,7 +168,7 @@ class Camera(BaseCamera):
                 if senh.add_frame(frame):  # it is a proper image....
 
 
-                    #------------------------------ BRUTAL ------------
+                    #------------------------------ BRUTAL ------------test exposure V4L
                     if (BaseCamera.nframes % 10==0):
                         cc = v4lc.V4L2_CTL("/dev/video"+str(vidnum))
                         capa = cc.get_capbilities()
@@ -184,10 +186,19 @@ class Camera(BaseCamera):
                     #--------------------------------------------------------------------------
 
 
+
                     # ----------  I need to calculate histogram before labels...
                     if histogram: # just calculate a number on plain frame
                         hmean = senh.histo_mean( )
 
+                    if False:
+                        print("D... HERE I MUST GIVE subtraction of mask")
+                        senh.subtract()
+
+                    # - compensate for speed of the sky
+                    if (speedx!=0) or (speedy!=0):
+                        senh.translate( speedx, speedy)
+
                     #--------------- now apply labels ------i cannot get rid in DETM---
                     #--------- all this will be on all rames histo,detect,direct,delta
                     senh.setbox(" ", senh.TIME)
@@ -233,8 +244,7 @@ class Camera(BaseCamera):
                     if timelaps>0:
                         senh.save_avi( seconds = timelaps )
 
-                    # if True:
-                    #     senh.crosson( 0,0)
+
 
                     #------------yield the resulting frame-----------------------------
                     if target_frame in ["detect","delta","histo"]:
