@@ -186,17 +186,19 @@ def display2(videodev, save = False,
 #----------------------------------------------------------------
 
         sfilename = ""
+        sfilenamea = ""
         if save:
             sname = "rec"
-            sfilename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
+            sfilenamea = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
             sme = socket.gethostname()
-            sfilename = f"{sme}{sname}_{sfilename}.avi"
+            sfilenamea = f"{sme}{sname}_{sfilenamea}.avi"
+            sfilenamea = os.path.expanduser("~/" + sfilenamea)
             sfourcc = cv2.VideoWriter_fourcc(*'XVID')
-            saviout = cv2.VideoWriter( sfilename , sfourcc , 25.0, (640,480))
-            print( sfilename )
-            print( sfilename )
-            print( sfilename )
-            print( sfilename )
+            saviout = cv2.VideoWriter( sfilenamea,sfourcc,25.0, (640,480))
+            print( sfilenamea )
+            print( sfilenamea )
+            print( sfilenamea )
+            print( sfilenamea )
 
 
         first = True
@@ -239,7 +241,7 @@ def display2(videodev, save = False,
                                     print("got  Size={:6.0f}kB {} {}".format(
                                         len(bytex)/1024,
                                         datetime.datetime.now(),
-                                        sfilename
+                                        sfilenamea
                                     ) , end="\r")
                                 else:
                                     ret_val = 0
@@ -289,6 +291,7 @@ def display2(videodev, save = False,
                     sfilename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                     sme = socket.gethostname()
                     sfilename = f"{sme}{sname}_{sfilename}.jpg"
+                    sfilename = os.path.expanduser( "~/"+sfilename )
                     # sfourcc = cv2.VideoWriter_fourcc(*'XVID')
                     # saviout = cv2.VideoWriter( sfilename , sfourcc , 25.0, (640,480))
                     isWritten = cv2.imwrite( sfilename, frame )
